@@ -1,15 +1,9 @@
-#' @importFrom htmltools htmlDependency
-#' @importFrom htmlwidgets shinyRenderWidget shinyWidgetOutput sizingPolicy createWidget
-#' @import grid
-#' @import ggplot2
-#' @importFrom grDevices dev.off
-
-#' @title Create a ggiraph object
+#' @title Create a ggiraph object (deprecated)
 #'
 #' @description Create an interactive graphic to be used in a web browser.
 #'
-#' This function is maintained for backward compatibility reasons, user should
-#' now use function [girafe()] and [girafe_options()].
+#' This function is now deprecated, users should
+#' now use function [girafe()].
 #'
 #' @inheritParams girafe
 #' @param width widget width ratio (0 < width <= 1).
@@ -26,10 +20,8 @@
 #' @param selected_css css to apply when element is selected (shiny only).
 #' @param dep_dir Deprecated; the path where the output files are stored. If `NULL`,
 #'  the current path for temporary files is used.
-#' @examples
-#' # ggiraph simple example -------
-#' @example examples/geom_point_interactive.R
 #' @export
+#' @keywords internal
 ggiraph <- function(code, ggobj = NULL,
                     pointsize = 12,
                     width = .75,
@@ -45,27 +37,27 @@ ggiraph <- function(code, ggobj = NULL,
                     selected_css = NULL,
                     dep_dir = NULL,
                     ...) {
-
+  message("Function `ggiraph()` is replaced by `girafe()` and will be removed soon.")
   if( !missing(dep_dir) ){
     warning("argument `dep_dir` has been deprecated.")
   }
 
   x <- girafe(code = code, ggobj = ggobj, pointsize = pointsize,
-         width_svg = width_svg, height_svg = height_svg, ...)
+              width_svg = width_svg, height_svg = height_svg, ...)
   x <- girafe_options(
     x = x,
     opts_tooltip(css = tooltip_extra_css,
-                opacity = tooltip_opacity,
-                use_cursor_pos = TRUE,
-                offx = tooltip_offx, offy = tooltip_offy,
-                delay_mouseover = 200, delay_mouseout = 500,
-                zindex = tooltip_zindex),
+                 opacity = tooltip_opacity,
+                 use_cursor_pos = TRUE,
+                 offx = tooltip_offx, offy = tooltip_offy,
+                 delay_mouseover = 200, delay_mouseout = 500,
+                 zindex = tooltip_zindex),
     opts_zoom(min = 1, max = zoom_max),
     opts_selection(type = selection_type, css = selected_css),
     opts_toolbar(position = "top", saveaspng = FALSE),
     opts_hover(css = hover_css),
     opts_sizing(rescale = TRUE, width = width)
-    )
+  )
 
   # fix for package ceterisParibus unit tests
   class(x) <- unique( c(class(x), "ggiraph"))
@@ -78,6 +70,8 @@ ggiraph <- function(code, ggobj = NULL,
 #' @title Create a ggiraph output element
 #' @description Render a ggiraph within an application page.
 #'
+#' This function is now deprecated, users should
+#' now use function [girafeOutput()].
 #' @param outputId output variable to read the ggiraph from.
 #' @param width widget width
 #' @param height widget height
@@ -93,12 +87,9 @@ ggiraph <- function(code, ggobj = NULL,
 #' }
 #' }
 #' @export
+#' @keywords internal
 ggiraphOutput <- function(outputId, width = "100%", height = "500px"){
-  # if( "auto" %in% height )
-  #   stop("'height:auto' is not supported", call. = FALSE)
-  # if( "auto" %in% width )
-  #   stop("'width:auto' is not supported", call. = FALSE)
-
+  .Deprecated(new = "girafeOutput")
   shinyWidgetOutput(outputId, 'girafe', package = 'ggiraph', width = width, height = height)
 }
 
@@ -106,6 +97,8 @@ ggiraphOutput <- function(outputId, width = "100%", height = "500px"){
 #'
 #' @description Makes a reactive version of a ggiraph object for use in Shiny.
 #'
+#' This function is now deprecated, users should
+#' now use function [renderGirafe()].
 #' @param expr An expression that returns a [ggiraph()] object.
 #' @param env The environment in which to evaluate expr.
 #' @param quoted Is `expr` a quoted expression
@@ -117,8 +110,10 @@ ggiraphOutput <- function(outputId, width = "100%", height = "500px"){
 #' }
 #' }
 #' @export
+#' @keywords internal
 renderggiraph <- function(expr, env = parent.frame(), quoted = FALSE) {
-	if (!quoted) { expr <- substitute(expr) } # force quoted
+  .Deprecated(new = "renderGirafe")
+  if (!quoted) { expr <- substitute(expr) } # force quoted
 	shinyRenderWidget(expr, girafeOutput, env, quoted = TRUE)
 }
 
